@@ -1,9 +1,11 @@
+/* Modified for R_xlen_t 26/06/2015 */
+
 #include <stdio.h>
 #include <ctype.h>
 #include <R.h>
 #include <Rinternals.h>
+#include <zlib.h>
 #include "uncertain.h"
-#include "zlib.h"
 
 #define BUFFERSIZE 1024
 /* wc function */
@@ -11,8 +13,8 @@
 void gzwc(const gzFile infile, const int nline, 
 	  long *chars, long *words, long *lines){
   int ch;
-  int sp=1;
-
+  int sp=1;  /* Was previous character read a white space character? */
+  int wol=0; /* Words on current line */
   *chars = 0;
   *words = 0;
   *lines = 0;
@@ -20,13 +22,18 @@ void gzwc(const gzFile infile, const int nline,
     ++(*chars);
     if(isspace(ch)) 
       sp=1;
-    else if(sp) {
+    else if(sp) { /* Previous character is whitespace, but this one isn't */
       ++(*words);
+      ++wol;
       sp=0;
     }
-    if (ch=='\n') 
+    if (ch=='\n') { /* Should detect line break on all OS's */
       ++(*lines);
+      wol = 0;
+    }
   }
+  if (wol)  /* Final line without terminating LF */
+    ++(*lines);
   gzrewind(infile);
   return;
 }
@@ -70,8 +77,10 @@ SEXP read_mach(const SEXP Filename, const SEXP Colnames, const SEXP Nsubject) {
   int ncol;
   if (!nsubj) {
     gzwc(infile, 0, &chars, &words, &lines);
-    if (words%lines)
-      error("Number of fields is not a multiple of number of lines");
+    int over = words%lines;
+    if (over) {
+      error("Number of fields, %ld,  is not a multiple of the number of lines, %ld", words, lines);
+    }
     ncol = words/lines - 2;
   }
   else {
@@ -98,7 +107,8 @@ SEXP read_mach(const SEXP Filename, const SEXP Colnames, const SEXP Nsubject) {
   SEXP Result, Dimnames, Rnames=R_NilValue, Package, Class;
   PROTECT(Result = allocMatrix(RAWSXP, lines, ncol));
   unsigned char *result = RAW(Result);
-  memset(result, 0x00, lines*ncol);
+  R_xlen_t len = (R_xlen_t)lines * (R_xlen_t)ncol;
+  memset(result, 0x00, len);
   PROTECT(Dimnames = allocVector(VECSXP, 2));
   PROTECT(Rnames = allocVector(STRSXP, lines));
   SET_VECTOR_ELT(Dimnames, 0, Rnames);
@@ -139,7 +149,8 @@ SEXP read_mach(const SEXP Filename, const SEXP Colnames, const SEXP Nsubject) {
     gznext(infile, buffer, BUFFERSIZE);
     if ((strcmp(buffer, "ML_PROB")!=0) && (strcmp(buffer, "PROB")!=0))
       error("file does not appear to be an MLPROB file (field 2=%s)", buffer);
-    for (int j=0, ij=i; j<ncol; j++, ij+=lines) {
+    R_xlen_t ij = i;
+    for (int j=0; j<ncol; j++, ij+=lines) {
       double pAA, pAB;
       gznext(infile, buffer, BUFFERSIZE);
       if (sscanf(buffer, "%lf", &pAA)!=1)
@@ -236,7 +247,8 @@ SEXP read_impute(const SEXP Filename, const SEXP Rownames, const SEXP Nsnp,
   SEXP Result, Dimnames, Colnames, Package, Class, Rnames=R_NilValue;
   PROTECT(Result = allocMatrix(RAWSXP, N, nsnp));
   unsigned char *result = RAW(Result);
-  memset(result, 0x00, N*nsnp);
+  R_xlen_t len = (R_xlen_t)N * (R_xlen_t)nsnp;
+  memset(result, 0x00, len);
   PROTECT(Dimnames = allocVector(VECSXP, 2));
   PROTECT(Colnames = allocVector(STRSXP, nsnp));
   SET_VECTOR_ELT(Dimnames, 1, Colnames);
@@ -292,7 +304,8 @@ SEXP read_impute(const SEXP Filename, const SEXP Rownames, const SEXP Nsnp,
 
   /* Read in data */
 
-  for (int i=0, ij=0; i<nsnp; i++) {
+  R_xlen_t ij = 0;
+  for (int i=0; i<nsnp; i++) {
     for (int j=0; j<ncol_skip; j++) {
       gznext(infile, buffer, BUFFERSIZE);
       if (j==snpcol) {
